==> nextcloud-9.0.53.tar.bz2: nextcloud/apps/files_sharing/l10n/en_GB.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Server to server sharing is not enabled on this server",
    "The mountpoint name contains invalid characters." : "The mountpoint name contains invalid characters.",
    "Not allowed to create a federated share with the same user server" : "Not allowed to create a federated share with the same user server",
    "Invalid or untrusted SSL certificate" : "Invalid or untrusted SSL certificate",
    "Could not authenticate to remote share, password might be wrong" : "Could not authenticate to remote share, password might be wrong",
    "Storage not valid" : "Storage not valid",
    "Couldn't add remote share" : "Couldn't add remote share",
    "Shared with you" : "Shared with you",
    "Shared with others" : "Shared with others",
    "Shared by link" : "Shared by link",
    "Federated sharing" : "Federated sharing",
    "Nothing shared with you yet" : "Nothing shared with you yet",
    "Files and folders others share with you will show up here" : "Files and folders others share with you will show up here",
    "Nothing shared yet" : "Nothing shared yet",
    "Files and folders you share will show up here" : "Files and folders you share will show up here",
    "No shared links" : "No shared links",
    "Files and folders you share by link will show up here" : "Files and folders you share by link will show up here",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Do you want to add the remote share {name} from {owner}@{remote}?",
    "Remote share" : "Remote share",
    "Remote share password" : "Remote share password",
    "Cancel" : "Cancel",
    "Add remote share" : "Add remote share",
    "You can upload into this folder" : "You can upload into this folder",
    "No ownCloud installation (7 or higher) found at {remote}" : "No ownCloud installation (7 or higher) found at {remote}",
    "Invalid ownCloud url" : "Invalid ownCloud URL",
    "Shared by" : "Shared by",
    "Sharing" : "Sharing",
    "A file or folder has been <strong>shared</strong>" : "A file or folder has been <strong>shared</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "A file or folder was shared from <strong>another server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "A public shared file or folder was <strong>downloaded</strong>",
    "You received a new remote share %2$s from %1$s" : "You received a new remote share %2$s from %1$s",
    "You received a new remote share from %s" : "You received a new remote share from %s",
    "%1$s accepted remote share %2$s" : "%1$s accepted remote share %2$s",
    "%1$s declined remote share %2$s" : "%1$s declined remote share %2$s",
    "%1$s unshared %2$s from you" : "%1$s unshared %2$s from you",
    "Public shared folder %1$s was downloaded" : "Public shared folder %1$s was downloaded",
    "Public shared file %1$s was downloaded" : "Public shared file %1$s was downloaded",
    "You shared %1$s with %2$s" : "You shared %1$s with %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s shared %1$s with %3$s",
    "You removed the share of %2$s for %1$s" : "You removed the share of %2$s for %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s removed the share of %3$s for %1$s",
    "You shared %1$s with group %2$s" : "You shared %1$s with group %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s shared %1$s with group %3$s",
    "You removed the share of group %2$s for %1$s" : "You removed the share of group %2$s for %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s removed the share of group %3$s for %1$s",
    "%2$s shared %1$s via link" : "%2$s shared %1$s via link",
    "You shared %1$s via link" : "You shared %1$s via link",
    "You removed the public link for %1$s" : "You removed the public link for %1$s",
    "%2$s removed the public link for %1$s" : "%2$s removed the public link for %1$s",
    "Your public link for %1$s expired" : "Your public link for %1$s expired",
    "The public link of %2$s for %1$s expired" : "The public link of %2$s for %1$s expired",
    "%2$s shared %1$s with you" : "%2$s shared %1$s with you",
    "%2$s removed the share for %1$s" : "%2$s removed the share for %1$s",
    "Downloaded via public link" : "Downloaded via public link",
    "Shared with %2$s" : "Shared with %2$s",
    "Shared with %3$s by %2$s" : "Shared with %3$s by %2$s",
    "Removed share for %2$s" : "Removed share for %2$s",
    "%2$s removed share for %3$s" : "%2$s removed share for %3$s",
    "Shared with group %2$s" : "Shared with group %2$s",
    "Shared with group %3$s by %2$s" : "Shared with group %3$s by %2$s",
    "Removed share of group %2$s" : "Removed share of group %2$s",
    "%2$s removed share of group %3$s" : "%2$s removed share of group %3$s",
    "Shared via link by %2$s" : "Shared via link by %2$s",
    "Shared via public link" : "Shared via public link",
    "Removed public link" : "Removed public link",
    "%2$s removed public link" : "%2$s removed public link",
    "Public link expired" : "Public link expired",
    "Public link of %2$s expired" : "Public link of %2$s expired",
    "Shared by %2$s" : "Shared by %2$s",
    "Shares" : "Shares",
    "You received \"/%2$s\" as a remote share from %1$s" : "You received \"/%2$s\" as a remote share from %1$s",
    "Accept" : "Accept",
    "Decline" : "Decline",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Share with me through my #ownCloud Federated Cloud ID, see %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Share with me through my #ownCloud Federated Cloud ID",
    "This share is password-protected" : "This share is password-protected",
    "The password is wrong. Try again." : "The password is wrong. Try again.",
    "Password" : "Password",
    "No entries found in this folder" : "No entries found in this folder",
    "Name" : "Name",
    "Share time" : "Share time",
    "Sorry, this link doesn’t seem to work anymore." : "Sorry, this link doesn’t seem to work anymore.",
    "Reasons might be:" : "Reasons might be:",
    "the item was removed" : "the item was removed",
    "the link expired" : "the link expired",
    "sharing is disabled" : "sharing is disabled",
    "For more info, please ask the person who sent this link." : "For more info, please ask the person who sent this link.",
    "Add to your Nextcloud" : "Add to your Nextcloud",
    "Download" : "Download",
    "Download %s" : "Download %s",
    "Direct link" : "Direct link",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Open documentation",
    "Allow users on this server to send shares to other servers" : "Allow users on this server to send shares to other servers",
    "Allow users on this server to receive shares from other servers" : "Allow users on this server to receive shares from other servers",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Your Federated Cloud ID:",
    "Share it:" : "Share it:",
    "Add to your website" : "Add to your website",
    "Share with me via ownCloud" : "Share with me via ownCloud",
    "HTML Code:" : "HTML Code:",
    "Public link of %2$s expired" : "Public link of %2$s expired",
    "Public shared file %1$s was downloaded" : "Public shared file %1$s was downloaded",
    "Public shared folder %1$s was downloaded" : "Public shared folder %1$s was downloaded",
    "Removed share for %2$s" : "Removed share for %2$s",
    "Removed share of group %2$s" : "Removed share of group %2$s",
    "Shared by %2$s" : "Shared by %2$s",
    "Shared via link by %2$s" : "Shared via link by %2$s",
    "Shared with group %3$s by %2$s" : "Shared with group %3$s by %2$s",
    "The public link of %2$s for %1$s expired" : "The public link of %2$s for %1$s expired",
    "You removed the public link for %1$s" : "You removed the public link for %1$s",
    "You removed the share of %2$s for %1$s" : "You removed the share of %2$s for %1$s",
    "You removed the share of group %2$s for %1$s" : "You removed the share of group %2$s for %1$s",
    "Your public link for %1$s expired" : "Your public link for %1$s expired"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-10.0.2.tar.bz2: nextcloud/apps/files_sharing/l10n/en_GB.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Shared with you",
    "Shared with others" : "Shared with others",
    "Shared by link" : "Shared by link",
    "Nothing shared with you yet" : "Nothing shared with you yet",
    "Files and folders others share with you will show up here" : "Files and folders others share with you will show up here",
    "Nothing shared yet" : "Nothing shared yet",
    "Files and folders you share will show up here" : "Files and folders you share will show up here",
    "No shared links" : "No shared links",
    "Files and folders you share by link will show up here" : "Files and folders you share by link will show up here",
    "You can upload into this folder" : "You can upload into this folder",
    "No expiration date set" : "No expiration date set",
    "Shared by" : "Shared by",
    "Sharing" : "Sharing",
    "Share API is disabled" : "Share API is disabled",
    "Wrong share ID, share doesn't exist" : "Wrong share ID, share doesn't exist",
    "Could not delete share" : "Could not delete share",
    "Please specify a file or folder path" : "Please specify a file or folder path",
    "Wrong path, file/folder doesn't exist" : "Wrong path, file/folder doesn't exist",
    "Please specify a valid user" : "Please specify a valid user",
    "Group sharing is disabled by the administrator" : "Group sharing is disabled by the administrator",
    "Please specify a valid group" : "Please specify a valid group",
    "Public link sharing is disabled by the administrator" : "Public link sharing is disabled by the administrator",
    "Public upload disabled by the administrator" : "Public upload disabled by the administrator",
    "Public upload is only possible for publicly shared folders" : "Public upload is only possible for publicly shared folders",
    "Invalid date, date format must be YYYY-MM-DD" : "Invalid date, date format must be YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Sharing %s failed because the back end does not allow shares from type %s",
    "Unknown share type" : "Unknown share type",
    "Not a directory" : "Not a directory",
    "Could not lock path" : "Could not lock path",
    "Can't change permissions for public share links" : "Can't change permissions for public share links",
    "Wrong or no update parameter given" : "Wrong or no update parameter given",
    "Cannot increase permissions" : "Cannot increase permissions",
    "A file or folder has been <strong>shared</strong>" : "A file or folder has been <strong>shared</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "A file or folder was shared from <strong>another server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "A public shared file or folder was <strong>downloaded</strong>",
    "You received a new remote share %2$s from %1$s" : "You received a new remote share %2$s from %1$s",
    "You received a new remote share from %s" : "You received a new remote share from %s",
    "%1$s accepted remote share %2$s" : "%1$s accepted remote share %2$s",
    "%1$s declined remote share %2$s" : "%1$s declined remote share %2$s",
    "%1$s unshared %2$s from you" : "%1$s unshared %2$s from you",
    "Public shared folder %1$s was downloaded" : "Public shared folder %1$s was downloaded",
    "Public shared file %1$s was downloaded" : "Public shared file %1$s was downloaded",
    "You shared %1$s with %2$s" : "You shared %1$s with %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s shared %1$s with %3$s",
    "You removed the share of %2$s for %1$s" : "You removed the share of %2$s for %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s removed the share of %3$s for %1$s",
    "You shared %1$s with group %2$s" : "You shared %1$s with group %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s shared %1$s with group %3$s",
    "You removed the share of group %2$s for %1$s" : "You removed the share of group %2$s for %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s removed the share of group %3$s for %1$s",
    "%2$s shared %1$s via link" : "%2$s shared %1$s via link",
    "You shared %1$s via link" : "You shared %1$s via link",
    "You removed the public link for %1$s" : "You removed the public link for %1$s",
    "%2$s removed the public link for %1$s" : "%2$s removed the public link for %1$s",
    "Your public link for %1$s expired" : "Your public link for %1$s expired",
    "The public link of %2$s for %1$s expired" : "The public link of %2$s for %1$s expired",
    "%2$s shared %1$s with you" : "%2$s shared %1$s with you",
    "%2$s removed the share for %1$s" : "%2$s removed the share for %1$s",
    "Downloaded via public link" : "Downloaded via public link",
    "Shared with %2$s" : "Shared with %2$s",
    "Shared with %3$s by %2$s" : "Shared with %3$s by %2$s",
    "Removed share for %2$s" : "Removed share for %2$s",
    "%2$s removed share for %3$s" : "%2$s removed share for %3$s",
    "Shared with group %2$s" : "Shared with group %2$s",
    "Shared with group %3$s by %2$s" : "Shared with group %3$s by %2$s",
    "Removed share of group %2$s" : "Removed share of group %2$s",
    "%2$s removed share of group %3$s" : "%2$s removed share of group %3$s",
    "Shared via link by %2$s" : "Shared via link by %2$s",
    "Shared via public link" : "Shared via public link",
    "Removed public link" : "Removed public link",
    "%2$s removed public link" : "%2$s removed public link",
    "Public link expired" : "Public link expired",
    "Public link of %2$s expired" : "Public link of %2$s expired",
    "Shared by %2$s" : "Shared by %2$s",
    "Shares" : "Shares",
    "This share is password-protected" : "This share is password-protected",
    "The password is wrong. Try again." : "The password is wrong. Try again.",
    "Password" : "Password",
    "No entries found in this folder" : "No entries found in this folder",
    "Name" : "Name",
    "Share time" : "Share time",
    "Expiration date" : "Expiration date",
    "Sorry, this link doesn’t seem to work anymore." : "Sorry, this link doesn’t seem to work anymore.",
    "Reasons might be:" : "Reasons might be:",
    "the item was removed" : "the item was removed",
    "the link expired" : "the link expired",
    "sharing is disabled" : "sharing is disabled",
    "For more info, please ask the person who sent this link." : "For more info, please ask the person who sent this link.",
    "Download" : "Download",
    "Download %s" : "Download %s",
    "Direct link" : "Direct link",
    "Upload files to %s" : "Upload files to %s",
    "Select or drop files" : "Select or drop files",
    "Uploading files…" : "Uploading files…",
    "Uploaded files:" : "Uploaded files:"
},
"nplurals=2; plural=(n != 1);");
